@@ -73,11 +73,9 @@ from pycadf.helper import api
 from pycadf import measurement as cadf_measurement
 from pycadf import metric as cadf_metric
 from pycadf import resource as cadf_resource
-import six
-import six.moves.queue as queue
-import six.moves.urllib.parse as urlparse
+import queue
 import threading
-
+import urllib.parse as urlparse
 
 LOG = logging.getLogger(__name__)
 
@@ -162,10 +160,24 @@ class Swift(object):
 
         self.ignore_projects = self._get_ignore_projects(conf)
 
+        extra_config_files = conf.get('extra_config_files')
+        if extra_config_files is not None:
+            extra_config_files = list_from_csv(extra_config_files)
+
+        extra_config_dirs = conf.get('extra_config_dirs')
+        if extra_config_dirs is not None:
+            extra_config_dirs = list_from_csv(extra_config_dirs)
+
+        oslo_conf = cfg.ConfigOpts()
+        oslo_conf([], project='swift',
+                  default_config_files=extra_config_files,
+                  default_config_dirs=extra_config_dirs,
+                  validate_default_values=True)
+
         oslo_messaging.set_transport_defaults(conf.get('control_exchange',
                                                        'swift'))
         self._notifier = oslo_messaging.Notifier(
-            oslo_messaging.get_notification_transport(cfg.CONF,
+            oslo_messaging.get_notification_transport(oslo_conf,
                                                       url=conf.get('url')),
             publisher_id='ceilometermiddleware',
             driver=conf.get('driver', 'messagingv2'),
@@ -241,7 +253,7 @@ class Swift(object):
             return [client.projects.get(name_or_id)]
         except ksa_exc.NotFound:
             pass
-        if isinstance(name_or_id, six.binary_type):
+        if isinstance(name_or_id, bytes):
             name_or_id = name_or_id.decode('utf-8', 'strict')
         projects = client.projects.list(name=name_or_id)
         if not projects:
@@ -305,10 +317,7 @@ class Swift(object):
         for header in env:
             if header.startswith('HTTP_') and env[header]:
                 key = header[5:]
-                if isinstance(env[header], six.text_type):
-                    headers[key] = six.text_type(env[header])
-                else:
-                    headers[key] = str(env[header])
+                headers[key] = str(env[header])
 
         try:
             container = obj = None
